@@ -2,11 +2,12 @@ from pymeterreader.device_lib.base import BaseReader
 from pymeterreader.device_lib.meter_sml import SmlReader
 from pymeterreader.device_lib.test_meter_plain import PlainReader
 from pymeterreader.device_lib.sensor_bme280 import Bme280Reader
-from pymeterreader.device_lib.common import strip, Sample
+from pymeterreader.device_lib.common import strip, Sample, Device
 
 __all__ = ["BaseReader",
            "SmlReader",
            "PlainReader",
            'Bme280Reader',
            "strip",
-           "Sample"]
+           "Sample",
+           "Device"]
